@@ -158,6 +158,19 @@ class fillVars(object, cl_base.glob_attr):
         """hash пароля администратора сервиса FTP"""
         return self.getHash(self.Get('ld_ftp_pw'), self.Get('ld_encrypt'))
 
+    def get_ld_proxy_dn(self):
+        """DN сервиса Proxy"""
+        return "ou=%s,%s" %(self.Get('ld_proxy_login'),
+            self.Get('ld_services_dn'))
+
+    def get_ld_proxy_pw(self):
+        """пароль администратора сервиса Proxy"""
+        return cl_utils.genpassword().strip()
+
+    def get_ld_proxy_hash(self):
+        """hash пароля администратора сервиса Proxy"""
+        return self.getHash(self.Get('ld_proxy_pw'), self.Get('ld_encrypt'))
+
     def get_sr_mail_host(self):
         """имя компьютера с настроенным сервисом Mail"""
         fullHostName = "%s.%s"%(self.Get('os_net_hostname'),
@@ -452,6 +465,22 @@ class fillVars(object, cl_base.glob_attr):
             return "%s, 127.0.0.0/8" %osNetAllow.replace(",",", ")
         return "127.0.0.0/8"
 
+    def get_sr_proxy_net_allow_pass(self):
+        """Текст в squid.conf - доступные сети"""
+        netAllow = self.Get("sr_proxy_net_allow")
+        if netAllow:
+            netAllow = netAllow.split(",")
+            netAllow = map(lambda x: "acl localnet src %s"%x,netAllow)
+            netAllow = "\n".join(netAllow)
+            return netAllow
+        netAllow = self.Get("os_net_allow")
+        if netAllow:
+            netAllow = netAllow.split(",")
+            netAllow = map(lambda x: "acl localnet src %s"%x,netAllow)
+            netAllow = "\n".join(netAllow)
+            return netAllow
+        return "acl localnet src 127.0.0.1/32"
+
     def get_sr_samba_net_allow(self):
         """Доступные сети для сервиса Samba"""
         netAllow = self.Get("os_net_allow")
@@ -466,6 +495,13 @@ class fillVars(object, cl_base.glob_attr):
             return netAllow
         return ""
 
+    def get_sr_proxy_net_allow(self):
+        """Доступные сети для сервиса Proxy"""
+        netAllow = self.Get("os_net_allow")
+        if netAllow:
+            return netAllow
+        return ""
+
     def get_ld_repl_mail_dn(self):
         """DN ветки хранения реплицируемых алиасов"""
         return "ou=%s,%s" %(self.Get('ld_repl_mail_login'),
@@ -509,3 +545,10 @@ class fillVars(object, cl_base.glob_attr):
         if jabberHosts:
             return ", ".join(map(lambda x: '"'+x+'"', jabberHosts.split(",")))
         return ""
+
+    def get_sr_jabber_user_name(self):
+        """Имя jabber пользователя (левая часть jabber id)"""
+        userJid = self.Get("sr_jabber_user_id")
+        if userJid:
+            return userJid.partition('@')[0]
+        return ""
