@@ -108,6 +108,9 @@ class Data:
     #Тип группы
     ur_group_type = {'mode':"w"}
 
+    #Произвольный аттрибут группы
+    ur_group_attr = {'mode':"w"}
+
     #Полное имя группы
     ur_group_comment = {'mode':"w"}
 
@@ -154,6 +157,9 @@ class Data:
     # jabber id пользователя
     sr_jabber_user_id = {'mode':"w"}
 
+    # имя jabber пользователя (левая часть jabber id)
+    sr_jabber_user_name = {'mode':"w"}
+
     # шифрование при получении - ''/ssl
     sr_jabber_crypt = {'mode':"w",'value':'ssl'}
 
@@ -193,9 +199,6 @@ class Data:
     #имя устанавливаемого сервиса
     cl_pass_service = {'mode':"w"}
 
-    #проход при наложении профилей 1,2,3,4,5 и.т д
-    cl_pass_step = {'mode':"w"}
-
     #директория куда будут записаны данные удаленных пользователей
     sr_deleted_path = {'mode':"w",
                         'value':'/var/calculate/server-backup/deleted'}
@@ -324,6 +327,32 @@ class Data:
     # Директория для ftp
     sr_ftp_path = {'value':'/var/calculate/server-data/ftp'}
 
+    #-----------------------------------------------------
+    #Сервис Proxy
+    #-----------------------------------------------------
+    # имя компьютера с настроенным сервисом Proxy
+    sr_proxy_host = {}
+
+    #DN администратора сервиса Proxy (он, же DN сервиса)
+    ld_proxy_dn = {}
+
+    #имя администратора сервиса Proxy
+    ld_proxy_login = {'value':'Proxy'}
+
+    #пароль администратора сервиса Proxy
+    ld_proxy_pw = {}
+
+    #hash пароля администратора сервиса Proxy
+    ld_proxy_hash = {}
+
+    #Настроен или нет сервис Proxy
+    sr_proxy_set = {'mode':"w",
+                   'value':'off'}
+
+    # порт Proxy сервиса
+    sr_proxy_port = {'mode':"w",'value':'8080'}
+
+
     ##список накладываемых профилей при установке, наложении профилей
     cl_profile_path = {}
 
@@ -331,9 +360,11 @@ class Data:
     #файлы системы
     cl_root_path = {'value':'/'}
 
-    # Calculate плюс версия калкулэйта для записи в заголовок файла
-    # объединяемого с профилем
-    cl_ver = {'value':'Calculate-server 2.0.12'}
+    # имя программы
+    cl_name = {'value':'calculate-server'}
+
+    # версия программы
+    cl_ver = {'value':'2.1.0'}
 
     #DN LDAP ветки, в котором будут находится служебные ветки
     ld_ldap_dn = {}
@@ -385,6 +416,10 @@ class Data:
     sr_mail_net_allow = {}
     # Текст в main.cf - доступные сети
     sr_mail_net_allow_pass = {}
+    # Доступные сети для сервиса Proxy
+    sr_proxy_net_allow = {}
+    # Текст в squid.conf - доступные сети
+    sr_proxy_net_allow_pass = {}
 
     #DN ветки хранения реплицируемых алиасов
     ld_repl_mail_dn = {}
